@@ -165,9 +165,9 @@ def sigProfilerExtractor(input_type,
                          batch_size=1, 
                          cpu=-1, 
                          gpu=False, 
-                         nmf_init="alexandrov-lab-custom", 
+                         nmf_init="nndsvd_min", 
                          precision= "single", 
-                         matrix_normalization= "100X", 
+                         matrix_normalization= "gmm", 
                          seeds= "random", 
                          min_nmf_iterations= 10000, 
                          max_nmf_iterations=1000000, 
@@ -176,8 +176,10 @@ def sigProfilerExtractor(input_type,
                          nnls_add_penalty=0.05, 
                          nnls_remove_penalty=0.01,
                          initial_remove_penalty=0.05,
-                         refit_denovo_signatures=False,
+                         refit_denovo_signatures=True,
                          clustering_distance="cosine",
+                         export_probabilities=True,
+                         make_decomposition_plots=True,
                          get_all_signature_matrices= False): 
     memory_usage()
     """
@@ -225,8 +227,8 @@ def sigProfilerExtractor(input_type,
     
     matrix_normalization: A string. Method of normalizing the genome matrix before it is analyzed by NMF. Default is "log2". Other options are "gmm", "100X" or "no_normalization".         
     
-    nmf_init: A String. The initialization algorithm for W and H matrix of NMF. Options are 'random', 'nndsvd', 'nndsvda', 'nndsvdar' and 'alexandrov-lab-custom'
-              Default is 'alexandrov-lab-custom'.
+    nmf_init: A String. The initialization algorithm for W and H matrix of NMF. Options are 'random', 'nndsvd', 'nndsvda', 'nndsvdar' and 'nndsvd_min'
+              Default is 'nndsvd_min'.
     
     precision: A string. Values should be single or double. Default is single.
     
@@ -256,6 +258,10 @@ def sigProfilerExtractor(input_type,
     
     get_all_signature_matrices: A Boolean. If true, the Ws and Hs from all the NMF iterations are generated in the output.
     
+    export_probabilities: A Boolean. Defualt is True. If False, then doesn't create the probability matrix.
+    
+    make_decompostion_plots: A Boolean. Defualt is True. If False, then doesn't create the decomposition plots.
+    
     Returns
     -------
     To learn about the output, please visit https://osf.io/t6j7u/wiki/home/
@@ -359,6 +365,8 @@ def sigProfilerExtractor(input_type,
                         "initial_remove_penalty":initial_remove_penalty,
                         "refit_denovo_signatures":refit_denovo_signatures,
                         "dist":clustering_distance,
+                        "export_probabilities":export_probabilities,
+                        "make_decompostion_plots":make_decomposition_plots,
                         "get_all_signature_matrices":get_all_signature_matrices}
     
     
@@ -384,7 +392,11 @@ def sigProfilerExtractor(input_type,
     genome_build=opportunity_genome
     refgen=reference_genome
     refit_denovo_signatures
-    
+    #set the squence type ("genome" or "exome") for the tmb plot inside the make_final_solution function
+    if exome==False:
+        sequence="genome"
+    if exome==True:
+        sequence="exome"
     
     #setting seeds
     if seeds=="random":
@@ -803,7 +815,7 @@ def sigProfilerExtractor(input_type,
             information.append([processAvg, exposureAvg, processStd, exposureStd, clusterSilhouetteCoefficients, signature_total_mutations, signature_stats, all_similarities]) #Will be used during hierarchycal approach
             
             ################################# Export the results ###########################################################    
-            sub.export_information(loopResults, m, layer_directory, index, colnames, wall=wall)
+            sub.export_information(loopResults, m, layer_directory, index, colnames, wall=wall, sequence=sequence)
             
           
             
@@ -892,8 +904,7 @@ def sigProfilerExtractor(input_type,
         signature_total_mutations = sub.signature_plotting_text(signature_total_mutations, "Total Mutations", "integer")
         # make de novo solution(processAvg, allgenomes, layer_directory1)
         
-        
-       
+   
         
         
        
@@ -908,7 +919,7 @@ def sigProfilerExtractor(input_type,
         
         exposureAvg = sub.make_final_solution(processAvg, allgenomes, listOfSignatures, layer_directory1, m, index, \
                        allcolnames, process_std_error = processSTE, signature_stabilities = signature_stabilities, \
-                       signature_total_mutations = signature_total_mutations,denovo_exposureAvg  = denovo_exposureAvg, signature_stats = signature_stats, add_penalty=add_penalty, remove_penalty=remove_penalty, initial_remove_penalty=initial_remove_penalty)    
+                       signature_total_mutations = signature_total_mutations,denovo_exposureAvg  = denovo_exposureAvg, signature_stats = signature_stats, add_penalty=add_penalty, remove_penalty=remove_penalty, initial_remove_penalty=initial_remove_penalty, sequence=sequence)    
           
         #try:
         # create the folder for the final solution/ Decomposed Solution
@@ -939,7 +950,7 @@ def sigProfilerExtractor(input_type,
             processAvg = np.array(processAvg)
             genomes = np.array(genomes)
             
-        final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build, add_penalty=add_penalty, remove_penalty=remove_penalty, mutation_context=mutation_context)
+        final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build, add_penalty=add_penalty, remove_penalty=remove_penalty, mutation_context=mutation_context, make_decomposition_plots=make_decomposition_plots)
         
         # extract the global signatures and new signatures from the final_signatures dictionary
         globalsigs = final_signatures["globalsigs"]
@@ -959,7 +970,7 @@ def sigProfilerExtractor(input_type,
         
         
         exposureAvg = sub.make_final_solution(processAvg, genomes, allsigids, layer_directory2, m, index, colnames, \
-                                remove_sigs=True, attribution = attribution, denovo_exposureAvg  = exposureAvg , background_sigs=background_sigs, add_penalty=add_penalty, remove_penalty=remove_penalty, initial_remove_penalty=initial_remove_penalty, genome_build=genome_build)
+                                remove_sigs=True, attribution = attribution, denovo_exposureAvg  = exposureAvg , background_sigs=background_sigs, add_penalty=add_penalty, remove_penalty=remove_penalty, initial_remove_penalty=initial_remove_penalty, genome_build=genome_build, sequence=sequence,export_probabilities=export_probabilities)
         
         """#make the decomposition plots
         if m=="SBS96" or m=="96":
